@@ -209,7 +209,7 @@ public abstract class AbstractProcessor extends AbstractProcessorLight implement
                 }
             } catch (IOException ioe) {
                 if (getLog().isDebugEnabled()) {
-                    getLog().debug("Unable to write async data.", ioe);
+                    getLog().debug(sm.getString("abstractProcessor.asyncFail"), ioe);
                 }
                 status = SocketEvent.ERROR;
                 request.setAttribute(RequestDispatcher.ERROR_EXCEPTION, ioe);
@@ -239,7 +239,7 @@ public abstract class AbstractProcessor extends AbstractProcessorLight implement
 
         RequestInfo rp = request.getRequestProcessor();
         try {
-            rp.setStage(org.apache.coyote.Constants.STAGE_SERVICE);
+            rp.setStage(Constants.STAGE_SERVICE);
             if (!getAdapter().asyncDispatch(request, response, status)) {
                 setErrorState(ErrorState.CLOSE_NOW, null);
             }
@@ -251,7 +251,7 @@ public abstract class AbstractProcessor extends AbstractProcessorLight implement
             getLog().error(sm.getString("http11processor.request.process"), t);
         }
 
-        rp.setStage(org.apache.coyote.Constants.STAGE_ENDED);
+        rp.setStage(Constants.STAGE_ENDED);
 
         SocketState state;
 
@@ -265,8 +265,8 @@ public abstract class AbstractProcessor extends AbstractProcessorLight implement
             state = dispatchEndRequest();
         }
 
-        if (getLog().isDebugEnabled()) {
-            getLog().debug("Socket: [" + socketWrapper + "], Status in: [" + status + "], State out: [" + state + "]");
+        if (getLog().isTraceEnabled()) {
+            getLog().trace("Socket: [" + socketWrapper + "], Status in: [" + status + "], State out: [" + state + "]");
         }
 
         return state;
@@ -394,6 +394,14 @@ public abstract class AbstractProcessor extends AbstractProcessorLight implement
                 ack((ContinueResponseTiming) param);
                 break;
             }
+            case EARLY_HINTS: {
+                try {
+                    earlyHints();
+                } catch (IOException e) {
+                    handleIOException(e);
+                }
+                break;
+            }
             case CLIENT_FLUSH: {
                 action(ActionCode.COMMIT, null);
                 try {
@@ -594,6 +602,10 @@ public abstract class AbstractProcessor extends AbstractProcessorLight implement
                 addDispatch(DispatchType.NON_BLOCKING_WRITE);
                 break;
             }
+            case DISPATCH_ERROR: {
+                addDispatch(DispatchType.NON_BLOCKING_ERROR);
+                break;
+            }
             case DISPATCH_EXECUTE: {
                 executeDispatches();
                 break;
@@ -667,7 +679,7 @@ public abstract class AbstractProcessor extends AbstractProcessorLight implement
     /**
      * {@inheritDoc}
      * <p>
-     * Sub-classes of this base class represent a single request/response pair. The timeout to be processed is,
+     * Subclasses of this base class represent a single request/response pair. The timeout to be processed is,
      * therefore, the Servlet asynchronous processing timeout.
      */
     @Override
@@ -721,27 +733,69 @@ public abstract class AbstractProcessor extends AbstractProcessorLight implement
     }
 
 
+    /**
+     * When committing the response, we have to validate the set of headers, as well as set up the response filters.
+     *
+     * @throws IOException IO exception during commit
+     */
     protected abstract void prepareResponse() throws IOException;
 
 
+    /**
+     * Finish the current response.
+     *
+     * @throws IOException IO exception during the write
+     */
     protected abstract void finishResponse() throws IOException;
 
 
+    /**
+     * Process acknowledgment of the request.
+     *
+     * @param continueResponseTiming specifies when an acknowledgment should be sent
+     */
     protected abstract void ack(ContinueResponseTiming continueResponseTiming);
 
 
+    protected abstract void earlyHints() throws IOException;
+
+
+    /**
+     * Callback to write data from the buffer.
+     *
+     * @throws IOException IO exception during the write
+     */
     protected abstract void flush() throws IOException;
 
 
+    /**
+     * Queries if bytes are available in buffers.
+     *
+     * @param doRead {@code true} to perform a read when no bytes are availble
+     *
+     * @return the amount of bytes that are known to be available
+     */
     protected abstract int available(boolean doRead);
 
 
+    /**
+     * Set the specified byte chunk as the request body that will be read. This allows saving and processing requests.
+     *
+     * @param body the byte chunk containing all the request bytes
+     */
     protected abstract void setRequestBody(ByteChunk body);
 
 
+    /**
+     * The response is finished and no additional bytes need to be sent to the client.
+     */
     protected abstract void setSwallowResponse();
 
 
+    /**
+     * Swallowing bytes is required for pipelining requests, so this allows to avoid doing extra operations in case an
+     * error occurs and the connection is to be closed instead.
+     */
     protected abstract void disableSwallowRequest();
 
 
@@ -844,12 +898,22 @@ public abstract class AbstractProcessor extends AbstractProcessorLight implement
     }
 
 
+    /**
+     * @return {@code true} if it is known that the request body has been fully read
+     */
     protected abstract boolean isRequestBodyFullyRead();
 
 
+    /**
+     * When using non blocking IO, register to get a callback when polling determines that bytes are available for
+     * reading.
+     */
     protected abstract void registerReadInterest();
 
 
+    /**
+     * @return {@code true} if bytes can be written without blocking
+     */
     protected abstract boolean isReadyForWrite();
 
 
@@ -1010,9 +1074,9 @@ public abstract class AbstractProcessor extends AbstractProcessorLight implement
         // Set the socket wrapper so the access log can read the socket related
         // information (e.g. client IP)
         setSocketWrapper(socketWrapper);
-        // Setup the minimal request information
+        // Set up the minimal request information
         request.setStartTimeNanos(System.nanoTime());
-        // Setup the minimal response information
+        // Set up the minimal response information
         response.setStatus(400);
         response.setError();
         getAdapter().log(request, response, 0);
